CCL: ccl_parameters Struct Reference

CCL

Data Fields
ccl_parameters Struct Reference

`#include <ccl_core.h>`

## Data Fields
double | Omega_c
double | Omega_b
double | Omega_m
double | Omega_k
double | sqrtk
int | k_sign
double | w0
double | wa
double | H0
double | h
double | N_nu_mass
double | N_nu_rel
double | mnu
double | Omega_n_mass
double | Omega_n_rel
double | A_s
double | n_s
double | Omega_g
double | T_CMB
double | sigma_8
double | Omega_l
double | z_star
bool | has_mgrowth
int | nz_mgrowth
double * | z_mgrowth
double * | df_mgrowth

## Detailed Description

Struct containing the parameters defining a cosmology

## Field Documentation

## ◆ A_s

double ccl_parameters::A_s

## ◆ df_mgrowth

double* ccl_parameters::df_mgrowth

## ◆ h

double ccl_parameters::h

## ◆ H0

double ccl_parameters::H0

## ◆ has_mgrowth

bool ccl_parameters::has_mgrowth

## ◆ k_sign

int ccl_parameters::k_sign

Sign of the curvature k

## ◆ mnu

double ccl_parameters::mnu

## ◆ N_nu_mass

double ccl_parameters::N_nu_mass

## ◆ N_nu_rel

double ccl_parameters::N_nu_rel

## ◆ n_s

double ccl_parameters::n_s

## ◆ nz_mgrowth

int ccl_parameters::nz_mgrowth

## ◆ Omega_b

double ccl_parameters::Omega_b

Density of baryons relative to the critical density

## ◆ Omega_c

double ccl_parameters::Omega_c

Density of CDM relative to the critical density

## ◆ Omega_g

double ccl_parameters::Omega_g

## ◆ Omega_k

double ccl_parameters::Omega_k

Density of curvature relative to the critical density

## ◆ Omega_l

double ccl_parameters::Omega_l

## ◆ Omega_m

double ccl_parameters::Omega_m

Density of all matter relative to the critical density

## ◆ Omega_n_mass

double ccl_parameters::Omega_n_mass

## ◆ Omega_n_rel

double ccl_parameters::Omega_n_rel

## ◆ sigma_8

double ccl_parameters::sigma_8

## ◆ sqrtk

double ccl_parameters::sqrtk

Square root of the magnitude of curvature, k

## ◆ T_CMB

double ccl_parameters::T_CMB

## ◆ w0

double ccl_parameters::w0

## ◆ wa

double ccl_parameters::wa

## ◆ z_mgrowth

double* ccl_parameters::z_mgrowth

## ◆ z_star

double ccl_parameters::z_star

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_core.h